Stan Math Library: stan::return_type< T1, T2, T3, T4, T5, T6 > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::return_type< T1, T2, T3, T4, T5, T6 > Struct Template Reference

Metaprogram to calculate the base scalar return type resulting from promoting all the scalar types of the template parameters. More...

`#include <return_type.hpp>`

## Public Types
typedef boost::math::tools::promote_args< typename scalar_type< T1 >::type, typename scalar_type< T2 >::type, typename scalar_type< T3 >::type, typename scalar_type< T4 >::type, typename scalar_type< T5 >::type, typename scalar_type< T6 >::type >::type | type

## Detailed Description

### template<typename T1, typename T2 = double, typename T3 = double, typename T4 = double, typename T5 = double, typename T6 = double>
struct stan::return_type< T1, T2, T3, T4, T5, T6 >

Metaprogram to calculate the base scalar return type resulting from promoting all the scalar types of the template parameters.

Definition at line 19 of file return_type.hpp.

## Member Typedef Documentation

template<typename T1, typename T2 = double, typename T3 = double, typename T4 = double, typename T5 = double, typename T6 = double>

typedef boost::math::tools::promote_args<typename scalar_type<T1>::type, typename scalar_type<T2>::type, typename scalar_type<T3>::type, typename scalar_type<T4>::type, typename scalar_type<T5>::type, typename scalar_type<T6>::type>::type stan::return_type< T1, T2, T3, T4, T5, T6 >::type

Definition at line 27 of file return_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/meta/return_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.